@@ -420,7 +420,10 @@ class XLRDReader(FileHandler):
                     else:
                         sheets[tab] = self.__xlrd_sheet(sheet=xls_ws, handler=handler, buffer=buffer)
         finally:
-            self.__xls_file.close()
+            if self.__xls_file and hasattr(self.__xls_file, 'close'):
+                self.__xls_file.close()
+            else:
+                self.__xls_file = None
 
         if sheets:
             return sheets
