@@ -10,12 +10,12 @@ class JSONReader(FileHandler):
 
     def parse(self):
         if self.streams:
-            for handler, buffer in self.streams:
-                self.__parse(handler=handler, buffer=buffer)
+            for handler, buffer, kwargs in self.streams:
+                self.__parse(handler=handler, buffer=buffer, **kwargs)
         else:
             return self.__parse()
 
-    def __parse(self, handler=None, buffer=None):
+    def __parse(self, handler=None, buffer=None, **kwargs):
         data = list()
         row_num = 0
         header = None
@@ -28,7 +28,7 @@ class JSONReader(FileHandler):
                     header = converted_row
 
                 if handler and buffer <= len(data):
-                    handler(self.file_path, data, row_num - len(data) + 1, row_num)
+                    handler(self.file_path, data, row_num - len(data) + 1, row_num, **kwargs)
                     data.clear()
                     data.append(header)
 
@@ -36,7 +36,7 @@ class JSONReader(FileHandler):
 
         if data and handler:
             row_num -= 1
-            handler(self.file_path, data, row_num - len(data) + 1, row_num)
+            handler(self.file_path, data, row_num - len(data) + 1, row_num, **kwargs)
         elif not handler:
             return data
 
