@@ -11,14 +11,14 @@ class OpenReader(FileHandler):
 
     def parse(self):
         if self.streams:
-            for handler, buffer in self.streams:
-                self.__parse(handler=handler, buffer=buffer)
+            for handler, buffer, kwargs in self.streams:
+                self.__parse(handler=handler, buffer=buffer, **kwargs)
         else:
             return Lock(filename=self.file_path, mode=self.mode, timeout=self.timeout,
                         check_interval=self.check_interval, fail_when_locked=self.fail_when_locked, flags=self.flags,
                         **self.kwargs)
 
-    def __parse(self, handler, buffer):
+    def __parse(self, handler, buffer, **kwargs):
         data = list()
         row_num = 0
         header = None
@@ -32,7 +32,7 @@ class OpenReader(FileHandler):
                     header = converted_row
 
                 if buffer <= len(data):
-                    handler(self.file_path, data, row_num - len(data) + 1, row_num)
+                    handler(self.file_path, data, row_num - len(data) + 1, row_num, **kwargs)
                     data.clear()
                     data.append(header)
 
@@ -40,6 +40,6 @@ class OpenReader(FileHandler):
 
         if data:
             row_num -= 1
-            handler(self.file_path, data, row_num - len(data) + 1, row_num)
+            handler(self.file_path, data, row_num - len(data) + 1, row_num, **kwargs)
         else:
             return data
